summaryrefslogtreecommitdiffstats
path: root/chrome
diff options
context:
space:
mode:
Diffstat (limited to 'chrome')
-rw-r--r--chrome/browser/automation/automation_provider.cc16
-rw-r--r--chrome/browser/download/download_request_dialog_delegate_win.cc6
-rw-r--r--chrome/browser/download/download_request_dialog_delegate_win.h5
-rw-r--r--chrome/browser/login_prompt.cc5
-rw-r--r--chrome/browser/task_manager.cc2
-rw-r--r--chrome/browser/unload_uitest.cc10
-rw-r--r--chrome/browser/views/about_chrome_view.cc24
-rw-r--r--chrome/browser/views/about_chrome_view.h8
-rw-r--r--chrome/browser/views/bookmark_editor_view.cc10
-rw-r--r--chrome/browser/views/bookmark_editor_view.h4
-rw-r--r--chrome/browser/views/bug_report_view.cc9
-rw-r--r--chrome/browser/views/bug_report_view.h2
-rw-r--r--chrome/browser/views/clear_browsing_data.cc13
-rw-r--r--chrome/browser/views/clear_browsing_data.h5
-rw-r--r--chrome/browser/views/edit_keyword_controller.cc9
-rw-r--r--chrome/browser/views/edit_keyword_controller.h3
-rw-r--r--chrome/browser/views/external_protocol_dialog.cc10
-rw-r--r--chrome/browser/views/external_protocol_dialog.h4
-rw-r--r--chrome/browser/views/first_run_customize_view.cc2
-rw-r--r--chrome/browser/views/first_run_view.cc2
-rw-r--r--chrome/browser/views/first_run_view_base.cc5
-rw-r--r--chrome/browser/views/first_run_view_base.h2
-rw-r--r--chrome/browser/views/frame/browser_view.cc8
-rw-r--r--chrome/browser/views/hung_renderer_view.cc8
-rw-r--r--chrome/browser/views/importer_lock_view.cc6
-rw-r--r--chrome/browser/views/importer_lock_view.h3
-rw-r--r--chrome/browser/views/importer_view.cc6
-rw-r--r--chrome/browser/views/importer_view.h3
-rw-r--r--chrome/browser/views/importing_progress_view.cc6
-rw-r--r--chrome/browser/views/importing_progress_view.h2
-rw-r--r--chrome/browser/views/input_window.cc8
-rw-r--r--chrome/browser/views/jsmessage_box_dialog.cc10
-rw-r--r--chrome/browser/views/jsmessage_box_dialog.h3
-rw-r--r--chrome/browser/views/keyword_editor_view.cc2
-rw-r--r--chrome/browser/views/new_profile_dialog.cc8
-rw-r--r--chrome/browser/views/new_profile_dialog.h3
-rw-r--r--chrome/browser/views/options/advanced_page_view.cc9
-rw-r--r--chrome/browser/views/options/cookies_view.h2
-rw-r--r--chrome/browser/views/options/options_window_view.cc2
-rw-r--r--chrome/browser/views/options/passwords_exceptions_window_view.cc2
-rw-r--r--chrome/browser/views/page_info_window.cc2
-rw-r--r--chrome/browser/views/repost_form_warning_view.cc6
-rw-r--r--chrome/browser/views/repost_form_warning_view.h3
-rw-r--r--chrome/browser/views/restart_message_box.cc8
-rw-r--r--chrome/browser/views/restart_message_box.h2
-rw-r--r--chrome/browser/views/select_profile_dialog.cc4
-rw-r--r--chrome/browser/views/select_profile_dialog.h1
-rw-r--r--chrome/browser/views/shelf_item_dialog.cc12
-rw-r--r--chrome/browser/views/shelf_item_dialog.h5
-rw-r--r--chrome/browser/views/uninstall_dialog.cc4
-rw-r--r--chrome/browser/views/uninstall_dialog.h1
-rw-r--r--chrome/browser/views/user_data_dir_dialog.cc11
-rw-r--r--chrome/browser/views/user_data_dir_dialog.h4
-rw-r--r--chrome/common/message_box_flags.h7
-rw-r--r--chrome/common/temp_scaffolding_stubs.cc10
-rw-r--r--chrome/test/automation/automation_proxy.cc14
-rw-r--r--chrome/test/automation/automation_proxy.h14
-rw-r--r--chrome/test/automation/automation_proxy_uitest.cc23
-rw-r--r--chrome/views/view_unittest.cc6
-rw-r--r--chrome/views/window/dialog_client_view.cc48
-rw-r--r--chrome/views/window/dialog_delegate.cc16
-rw-r--r--chrome/views/window/dialog_delegate.h35
62 files changed, 223 insertions, 260 deletions
diff --git a/chrome/browser/automation/automation_provider.cc b/chrome/browser/automation/automation_provider.cc
index 8383feb..02a0a9e 100644
--- a/chrome/browser/automation/automation_provider.cc
+++ b/chrome/browser/automation/automation_provider.cc
@@ -28,6 +28,7 @@
#include "chrome/browser/tab_contents/web_contents.h"
#include "chrome/browser/tab_contents/tab_contents_view.h"
#include "chrome/common/chrome_paths.h"
+#include "chrome/common/message_box_flags.h"
#include "chrome/common/notification_registrar.h"
#include "chrome/common/platform_util.h"
#include "chrome/common/pref_service.h"
@@ -46,7 +47,6 @@
#include "chrome/browser/printing/print_job.h"
#include "chrome/browser/views/bookmark_bar_view.h"
#include "chrome/browser/views/location_bar_view.h"
-#include "chrome/views/window/dialog_delegate.h"
#include "chrome/views/window/window.h"
#endif // defined(OS_WIN)
@@ -1297,9 +1297,6 @@ void AutomationProvider::GetBrowserWindowCount(int* window_count) {
*window_count = static_cast<int>(BrowserList::size());
}
-#if defined(OS_WIN)
-// TODO(port): Move the views::DialogDelegate::DialogButton enum out into a
-// common place then remove the OS_WIN guard.
void AutomationProvider::GetShowingAppModalDialog(bool* showing_dialog,
int* dialog_button) {
AppModalDialog* dialog_delegate = AppModalDialogQueue::active_dialog();
@@ -1307,7 +1304,7 @@ void AutomationProvider::GetShowingAppModalDialog(bool* showing_dialog,
if (*showing_dialog)
*dialog_button = dialog_delegate->GetDialogButtons();
else
- *dialog_button = views::DialogDelegate::DIALOGBUTTON_NONE;
+ *dialog_button = MessageBox::DIALOGBUTTON_NONE;
}
void AutomationProvider::ClickAppModalDialogButton(int button, bool* success) {
@@ -1316,20 +1313,19 @@ void AutomationProvider::ClickAppModalDialogButton(int button, bool* success) {
AppModalDialog* dialog_delegate = AppModalDialogQueue::active_dialog();
if (dialog_delegate &&
(dialog_delegate->GetDialogButtons() & button) == button) {
- if ((button & views::DialogDelegate::DIALOGBUTTON_OK) ==
- views::DialogDelegate::DIALOGBUTTON_OK) {
+ if ((button & MessageBox::DIALOGBUTTON_OK) ==
+ MessageBox::DIALOGBUTTON_OK) {
dialog_delegate->AcceptWindow();
*success = true;
}
- if ((button & views::DialogDelegate::DIALOGBUTTON_CANCEL) ==
- views::DialogDelegate::DIALOGBUTTON_CANCEL) {
+ if ((button & MessageBox::DIALOGBUTTON_CANCEL) ==
+ MessageBox::DIALOGBUTTON_CANCEL) {
DCHECK(!*success) << "invalid param, OK and CANCEL specified";
dialog_delegate->CancelWindow();
*success = true;
}
}
}
-#endif
void AutomationProvider::GetBrowserWindow(int index, int* handle) {
*handle = 0;
diff --git a/chrome/browser/download/download_request_dialog_delegate_win.cc b/chrome/browser/download/download_request_dialog_delegate_win.cc
index 3f359ca..767bfee 100644
--- a/chrome/browser/download/download_request_dialog_delegate_win.cc
+++ b/chrome/browser/download/download_request_dialog_delegate_win.cc
@@ -46,10 +46,10 @@ views::View* DownloadRequestDialogDelegateWin::GetContentsView() {
}
std::wstring DownloadRequestDialogDelegateWin::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_MULTI_DOWNLOAD_WARNING_ALLOW);
- if (button == DIALOGBUTTON_CANCEL)
+ if (button == MessageBox::DIALOGBUTTON_CANCEL)
return l10n_util::GetString(IDS_MULTI_DOWNLOAD_WARNING_DENY);
return std::wstring();
}
diff --git a/chrome/browser/download/download_request_dialog_delegate_win.h b/chrome/browser/download/download_request_dialog_delegate_win.h
index 7e5f83f..df3dd01 100644
--- a/chrome/browser/download/download_request_dialog_delegate_win.h
+++ b/chrome/browser/download/download_request_dialog_delegate_win.h
@@ -32,9 +32,10 @@ class DownloadRequestDialogDelegateWin : public DownloadRequestDialogDelegate,
virtual bool Cancel();
virtual bool Accept();
virtual views::View* GetContentsView();
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual int GetDefaultDialogButton() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
virtual void DeleteDelegate();
diff --git a/chrome/browser/login_prompt.cc b/chrome/browser/login_prompt.cc
index c7b30c9..f60a2b6 100644
--- a/chrome/browser/login_prompt.cc
+++ b/chrome/browser/login_prompt.cc
@@ -128,8 +128,9 @@ class LoginHandlerImpl : public LoginHandler,
}
// views::DialogDelegate methods:
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_LOGIN_DIALOG_OK_BUTTON_LABEL);
return DialogDelegate::GetDialogButtonLabel(button);
}
diff --git a/chrome/browser/task_manager.cc b/chrome/browser/task_manager.cc
index c0f189b..2535d56 100644
--- a/chrome/browser/task_manager.cc
+++ b/chrome/browser/task_manager.cc
@@ -1079,7 +1079,7 @@ std::wstring TaskManager::GetWindowName() const {
}
int TaskManager::GetDialogButtons() const {
- return DIALOGBUTTON_NONE;
+ return MessageBox::DIALOGBUTTON_NONE;
}
void TaskManager::WindowClosing() {
diff --git a/chrome/browser/unload_uitest.cc b/chrome/browser/unload_uitest.cc
index a0e5a24..3a692be 100644
--- a/chrome/browser/unload_uitest.cc
+++ b/chrome/browser/unload_uitest.cc
@@ -136,9 +136,9 @@ class UnloadTest : public UITest {
EXPECT_TRUE(CloseBrowser(browser.get(), &application_closed));
}
- void ClickModalDialogButton(views::DialogDelegate::DialogButton button) {
+ void ClickModalDialogButton(MessageBox::DialogButton button) {
bool modal_dialog_showing = false;
- views::DialogDelegate::DialogButton available_buttons;
+ MessageBox::DialogButton available_buttons;
EXPECT_TRUE(automation()->WaitForAppModalDialog(3000));
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&available_buttons));
@@ -221,7 +221,7 @@ TEST_F(UnloadTest, BrowserCloseBeforeUnloadOK) {
NavigateToDataURL(BEFORE_UNLOAD_HTML, L"beforeunload");
CloseBrowserAsync(browser.get());
- ClickModalDialogButton(views::DialogDelegate::DIALOGBUTTON_OK);
+ ClickModalDialogButton(MessageBox::DIALOGBUTTON_OK);
WaitForBrowserClosed();
EXPECT_FALSE(IsBrowserRunning());
}
@@ -233,12 +233,12 @@ TEST_F(UnloadTest, BrowserCloseBeforeUnloadCancel) {
NavigateToDataURL(BEFORE_UNLOAD_HTML, L"beforeunload");
CloseBrowserAsync(browser.get());
- ClickModalDialogButton(views::DialogDelegate::DIALOGBUTTON_CANCEL);
+ ClickModalDialogButton(MessageBox::DIALOGBUTTON_CANCEL);
WaitForBrowserClosed();
EXPECT_TRUE(IsBrowserRunning());
CloseBrowserAsync(browser.get());
- ClickModalDialogButton(views::DialogDelegate::DIALOGBUTTON_OK);
+ ClickModalDialogButton(MessageBox::DIALOGBUTTON_OK);
WaitForBrowserClosed();
EXPECT_FALSE(IsBrowserRunning());
}
diff --git a/chrome/browser/views/about_chrome_view.cc b/chrome/browser/views/about_chrome_view.cc
index df605ab..88bf4d9 100644
--- a/chrome/browser/views/about_chrome_view.cc
+++ b/chrome/browser/views/about_chrome_view.cc
@@ -603,15 +603,11 @@ void AboutChromeView::ViewHierarchyChanged(bool is_add,
////////////////////////////////////////////////////////////////////////////////
// AboutChromeView, views::DialogDelegate implementation:
-int AboutChromeView::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
std::wstring AboutChromeView::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return l10n_util::GetString(IDS_ABOUT_CHROME_UPDATE_CHECK);
- } else if (button == DIALOGBUTTON_CANCEL) {
+ } else if (button == MessageBox::DIALOGBUTTON_CANCEL) {
// The OK button (which is the default button) has been re-purposed to be
// 'Check for Updates' so we want the Cancel button should have the label
// OK but act like a Cancel button in all other ways.
@@ -622,16 +618,22 @@ std::wstring AboutChromeView::GetDialogButtonLabel(
return L"";
}
-bool AboutChromeView::IsDialogButtonEnabled(DialogButton button) const {
- if (button == DIALOGBUTTON_OK && check_button_status_ != CHECKBUTTON_ENABLED)
+bool AboutChromeView::IsDialogButtonEnabled(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK &&
+ check_button_status_ != CHECKBUTTON_ENABLED) {
return false;
+ }
return true;
}
-bool AboutChromeView::IsDialogButtonVisible(DialogButton button) const {
- if (button == DIALOGBUTTON_OK && check_button_status_ == CHECKBUTTON_HIDDEN)
+bool AboutChromeView::IsDialogButtonVisible(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK &&
+ check_button_status_ == CHECKBUTTON_HIDDEN) {
return false;
+ }
return true;
}
diff --git a/chrome/browser/views/about_chrome_view.h b/chrome/browser/views/about_chrome_view.h
index 2118e76..44bdeacd 100644
--- a/chrome/browser/views/about_chrome_view.h
+++ b/chrome/browser/views/about_chrome_view.h
@@ -47,10 +47,10 @@ class AboutChromeView : public views::View,
views::View* child);
// Overridden from views::DialogDelegate:
- virtual int GetDialogButtons() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
- virtual bool IsDialogButtonVisible(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
+ virtual bool IsDialogButtonVisible(MessageBox::DialogButton button) const;
virtual bool CanResize() const;
virtual bool CanMaximize() const;
virtual bool IsAlwaysOnTop() const;
diff --git a/chrome/browser/views/bookmark_editor_view.cc b/chrome/browser/views/bookmark_editor_view.cc
index b5a2f6d..b2d8c79 100644
--- a/chrome/browser/views/bookmark_editor_view.cc
+++ b/chrome/browser/views/bookmark_editor_view.cc
@@ -80,8 +80,9 @@ void BookmarkEditorView::Show(HWND parent_hwnd,
editor->Show(parent_hwnd);
}
-bool BookmarkEditorView::IsDialogButtonEnabled(DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+bool BookmarkEditorView::IsDialogButtonEnabled(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
const GURL url(GetInputURL());
return bb_model_->IsLoaded() && url.is_valid();
}
@@ -96,7 +97,7 @@ std::wstring BookmarkEditorView::GetWindowTitle() const {
}
bool BookmarkEditorView::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK)) {
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK)) {
// The url is invalid, focus the url field.
url_tf_.SelectAll();
url_tf_.RequestFocus();
@@ -107,7 +108,8 @@ bool BookmarkEditorView::Accept() {
return true;
}
-bool BookmarkEditorView::AreAcceleratorsEnabled(DialogButton button) {
+bool BookmarkEditorView::AreAcceleratorsEnabled(
+ MessageBox::DialogButton button) {
return !show_tree_ || !tree_view_->GetEditingNode();
}
diff --git a/chrome/browser/views/bookmark_editor_view.h b/chrome/browser/views/bookmark_editor_view.h
index a307277..6b24aa4 100644
--- a/chrome/browser/views/bookmark_editor_view.h
+++ b/chrome/browser/views/bookmark_editor_view.h
@@ -86,11 +86,11 @@ class BookmarkEditorView : public views::View,
Handler* handler);
// DialogDelegate methods:
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual bool IsModal() const;
virtual std::wstring GetWindowTitle() const;
virtual bool Accept();
- virtual bool AreAcceleratorsEnabled(DialogButton button);
+ virtual bool AreAcceleratorsEnabled(MessageBox::DialogButton button);
virtual views::View* GetContentsView();
// View methods.
diff --git a/chrome/browser/views/bug_report_view.cc b/chrome/browser/views/bug_report_view.cc
index 647dfc1..ae313f2 100644
--- a/chrome/browser/views/bug_report_view.cc
+++ b/chrome/browser/views/bug_report_view.cc
@@ -266,8 +266,9 @@ bool BugReportView::HandleKeystroke(views::TextField* sender,
return false;
}
-std::wstring BugReportView::GetDialogButtonLabel(DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+std::wstring BugReportView::GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
if (problem_type_ == BugReportComboBoxModel::PHISHING_PAGE)
return l10n_util::GetString(IDS_BUGREPORT_SEND_PHISHING_REPORT);
else
@@ -278,7 +279,7 @@ std::wstring BugReportView::GetDialogButtonLabel(DialogButton button) const {
}
int BugReportView::GetDefaultDialogButton() const {
- return DIALOGBUTTON_NONE;
+ return MessageBox::DIALOGBUTTON_NONE;
}
bool BugReportView::CanResize() const {
@@ -306,7 +307,7 @@ std::wstring BugReportView::GetWindowTitle() const {
}
bool BugReportView::Accept() {
- if (IsDialogButtonEnabled(DIALOGBUTTON_OK)) {
+ if (IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK)) {
if (problem_type_ == BugReportComboBoxModel::PHISHING_PAGE)
ReportPhishing();
else
diff --git a/chrome/browser/views/bug_report_view.h b/chrome/browser/views/bug_report_view.h
index 22a2c42..5e8e1f2 100644
--- a/chrome/browser/views/bug_report_view.h
+++ b/chrome/browser/views/bug_report_view.h
@@ -61,7 +61,7 @@ class BugReportView : public views::View,
int new_index);
// Overridden from views::DialogDelegate:
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const;
virtual int GetDefaultDialogButton() const;
virtual bool CanResize() const;
virtual bool CanMaximize() const;
diff --git a/chrome/browser/views/clear_browsing_data.cc b/chrome/browser/views/clear_browsing_data.cc
index 5a0df99..d27c5b0 100644
--- a/chrome/browser/views/clear_browsing_data.cc
+++ b/chrome/browser/views/clear_browsing_data.cc
@@ -236,21 +236,22 @@ void ClearBrowsingDataView::ViewHierarchyChanged(bool is_add,
// ClearBrowsingDataView, views::DialogDelegate implementation:
std::wstring ClearBrowsingDataView::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return l10n_util::GetString(IDS_CLEAR_BROWSING_DATA_COMMIT);
- } else if (button == DIALOGBUTTON_CANCEL) {
+ } else if (button == MessageBox::DIALOGBUTTON_CANCEL) {
return l10n_util::GetString(IDS_CLOSE);
} else {
return std::wstring();
}
}
-bool ClearBrowsingDataView::IsDialogButtonEnabled(DialogButton button) const {
+bool ClearBrowsingDataView::IsDialogButtonEnabled(
+ MessageBox::DialogButton button) const {
if (delete_in_progress_)
return false;
- if (button == DIALOGBUTTON_OK) {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return del_history_checkbox_->checked() ||
del_downloads_checkbox_->checked() ||
del_cache_checkbox_->checked() ||
@@ -287,7 +288,7 @@ std::wstring ClearBrowsingDataView::GetWindowTitle() const {
}
bool ClearBrowsingDataView::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK)) {
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK)) {
return false;
}
diff --git a/chrome/browser/views/clear_browsing_data.h b/chrome/browser/views/clear_browsing_data.h
index 18912fc..77b9bd5 100644
--- a/chrome/browser/views/clear_browsing_data.h
+++ b/chrome/browser/views/clear_browsing_data.h
@@ -50,8 +50,9 @@ class ClearBrowsingDataView : public views::View,
views::View* child);
// Overridden from views::DialogDelegate:
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual bool CanResize() const;
virtual bool CanMaximize() const;
virtual bool IsAlwaysOnTop() const;
diff --git a/chrome/browser/views/edit_keyword_controller.cc b/chrome/browser/views/edit_keyword_controller.cc
index 1463777d..e0d5ad3 100644
--- a/chrome/browser/views/edit_keyword_controller.cc
+++ b/chrome/browser/views/edit_keyword_controller.cc
@@ -77,12 +77,9 @@ std::wstring EditKeywordController::GetWindowTitle() const {
IDS_SEARCH_ENGINES_EDITOR_NEW_WINDOW_TITLE);
}
-int EditKeywordController::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
-bool EditKeywordController::IsDialogButtonEnabled(DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+bool EditKeywordController::IsDialogButtonEnabled(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return (IsKeywordValid() && !title_tf_->GetText().empty() && IsURLValid());
}
return true;
diff --git a/chrome/browser/views/edit_keyword_controller.h b/chrome/browser/views/edit_keyword_controller.h
index 00a76fe..b9b846f 100644
--- a/chrome/browser/views/edit_keyword_controller.h
+++ b/chrome/browser/views/edit_keyword_controller.h
@@ -44,8 +44,7 @@ class EditKeywordController : public views::TextField::Controller,
// DialogDelegate overrides.
virtual bool IsModal() const;
virtual std::wstring GetWindowTitle() const;
- virtual int GetDialogButtons() const;
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual void DeleteDelegate();
virtual bool Cancel();
virtual bool Accept();
diff --git a/chrome/browser/views/external_protocol_dialog.cc b/chrome/browser/views/external_protocol_dialog.cc
index 50cdce3..e80fe99 100644
--- a/chrome/browser/views/external_protocol_dialog.cc
+++ b/chrome/browser/views/external_protocol_dialog.cc
@@ -43,17 +43,13 @@ ExternalProtocolDialog::~ExternalProtocolDialog() {
//////////////////////////////////////////////////////////////////////////////
// ExternalProtocolDialog, views::DialogDelegate implementation:
-int ExternalProtocolDialog::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
int ExternalProtocolDialog::GetDefaultDialogButton() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
std::wstring ExternalProtocolDialog::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_EXTERNAL_PROTOCOL_OK_BUTTON_TEXT);
// Set the button to have a default name.
diff --git a/chrome/browser/views/external_protocol_dialog.h b/chrome/browser/views/external_protocol_dialog.h
index 3936556..5c0c6a7 100644
--- a/chrome/browser/views/external_protocol_dialog.h
+++ b/chrome/browser/views/external_protocol_dialog.h
@@ -35,9 +35,9 @@ class ExternalProtocolDialog : public views::DialogDelegate {
virtual ~ExternalProtocolDialog();
// views::DialogDelegate Methods:
- virtual int GetDialogButtons() const;
virtual int GetDefaultDialogButton() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual std::wstring GetWindowTitle() const;
virtual void DeleteDelegate();
virtual bool Accept();
diff --git a/chrome/browser/views/first_run_customize_view.cc b/chrome/browser/views/first_run_customize_view.cc
index 1d0b469..8495cc9 100644
--- a/chrome/browser/views/first_run_customize_view.cc
+++ b/chrome/browser/views/first_run_customize_view.cc
@@ -178,7 +178,7 @@ views::View* FirstRunCustomizeView::GetContentsView() {
}
bool FirstRunCustomizeView::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK))
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK))
return false;
DisableButtons();
diff --git a/chrome/browser/views/first_run_view.cc b/chrome/browser/views/first_run_view.cc
index 24f5e11..fb988d1 100644
--- a/chrome/browser/views/first_run_view.cc
+++ b/chrome/browser/views/first_run_view.cc
@@ -171,7 +171,7 @@ views::View* FirstRunView::GetContentsView() {
}
bool FirstRunView::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK))
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK))
return false;
DisableButtons();
diff --git a/chrome/browser/views/first_run_view_base.cc b/chrome/browser/views/first_run_view_base.cc
index c3df0e2..2115d65 100644
--- a/chrome/browser/views/first_run_view_base.cc
+++ b/chrome/browser/views/first_run_view_base.cc
@@ -151,8 +151,9 @@ bool FirstRunViewBase::HasAlwaysOnTopMenu() const {
return false;
}
-std::wstring FirstRunViewBase::GetDialogButtonLabel(DialogButton button) const {
- if (DIALOGBUTTON_OK == button)
+std::wstring FirstRunViewBase::GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ if (MessageBox::DIALOGBUTTON_OK == button)
return l10n_util::GetString(IDS_FIRSTRUN_DLG_OK);
// The other buttons get the default text.
return std::wstring();
diff --git a/chrome/browser/views/first_run_view_base.h b/chrome/browser/views/first_run_view_base.h
index d4a08f7..7d16b9b7 100644
--- a/chrome/browser/views/first_run_view_base.h
+++ b/chrome/browser/views/first_run_view_base.h
@@ -39,7 +39,7 @@ class FirstRunViewBase : public views::View,
virtual bool HasAlwaysOnTopMenu() const;
// Overridden from views::DialogDelegate.
- std::wstring GetDialogButtonLabel(DialogButton button) const;
+ std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const;
protected:
// Returns the items that the first run process is required to import
diff --git a/chrome/browser/views/frame/browser_view.cc b/chrome/browser/views/frame/browser_view.cc
index 6cee57d..c9650f3 100644
--- a/chrome/browser/views/frame/browser_view.cc
+++ b/chrome/browser/views/frame/browser_view.cc
@@ -221,14 +221,14 @@ class DownloadInProgressConfirmDialogDelegate : public views::DialogDelegate,
// DialogDelegate implementation:
virtual int GetDefaultDialogButton() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+ virtual std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_DOWNLOAD_REMOVE_CONFIRM_OK_BUTTON_LABEL);
- DCHECK_EQ(DIALOGBUTTON_CANCEL, button);
+ DCHECK_EQ(MessageBox::DIALOGBUTTON_CANCEL, button);
return l10n_util::GetString(
IDS_DOWNLOAD_REMOVE_CONFIRM_CANCEL_BUTTON_LABEL);
}
diff --git a/chrome/browser/views/hung_renderer_view.cc b/chrome/browser/views/hung_renderer_view.cc
index 9d239e4..330c883 100644
--- a/chrome/browser/views/hung_renderer_view.cc
+++ b/chrome/browser/views/hung_renderer_view.cc
@@ -126,7 +126,7 @@ class HungRendererWarningView : public views::View,
virtual void WindowClosing();
virtual int GetDialogButtons() const;
virtual std::wstring GetDialogButtonLabel(
- views::DialogDelegate::DialogButton button) const;
+ MessageBox::DialogButton button) const;
virtual views::View* GetExtraView();
virtual bool Accept(bool window_closing);
virtual views::View* GetContentsView();
@@ -272,12 +272,12 @@ int HungRendererWarningView::GetDialogButtons() const {
// the OK button to wait for responsiveness (and close the dialog) and our
// additional button (which we create) to kill the process (which will result
// in the dialog being destroyed).
- return DIALOGBUTTON_OK;
+ return MessageBox::DIALOGBUTTON_OK;
}
std::wstring HungRendererWarningView::GetDialogButtonLabel(
- views::DialogDelegate::DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_BROWSER_HANGMONITOR_RENDERER_WAIT);
return std::wstring();
}
diff --git a/chrome/browser/views/importer_lock_view.cc b/chrome/browser/views/importer_lock_view.cc
index 7c6b809..8b4fa99 100644
--- a/chrome/browser/views/importer_lock_view.cc
+++ b/chrome/browser/views/importer_lock_view.cc
@@ -46,10 +46,10 @@ void ImporterLockView::Layout() {
}
std::wstring ImporterLockView::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return l10n_util::GetString(IDS_IMPORTER_LOCK_OK);
- } else if (button == DIALOGBUTTON_CANCEL) {
+ } else if (button == MessageBox::DIALOGBUTTON_CANCEL) {
return l10n_util::GetString(IDS_IMPORTER_LOCK_CANCEL);
}
return std::wstring();
diff --git a/chrome/browser/views/importer_lock_view.h b/chrome/browser/views/importer_lock_view.h
index e513bd4..1f91cb9 100644
--- a/chrome/browser/views/importer_lock_view.h
+++ b/chrome/browser/views/importer_lock_view.h
@@ -28,7 +28,8 @@ class ImporterLockView : public views::View,
virtual void Layout();
// Overridden from views::DialogDelegate:
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual bool IsModal() const;
virtual std::wstring GetWindowTitle() const;
virtual bool Accept();
diff --git a/chrome/browser/views/importer_view.cc b/chrome/browser/views/importer_view.cc
index c3dbbf0..46f3576 100644
--- a/chrome/browser/views/importer_view.cc
+++ b/chrome/browser/views/importer_view.cc
@@ -99,8 +99,8 @@ void ImporterView::Layout() {
}
std::wstring ImporterView::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return l10n_util::GetString(IDS_IMPORT_COMMIT);
} else {
return std::wstring();
@@ -116,7 +116,7 @@ std::wstring ImporterView::GetWindowTitle() const {
}
bool ImporterView::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK)) {
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK)) {
return false;
}
diff --git a/chrome/browser/views/importer_view.h b/chrome/browser/views/importer_view.h
index 9c6e7a8..422b5f9 100644
--- a/chrome/browser/views/importer_view.h
+++ b/chrome/browser/views/importer_view.h
@@ -37,7 +37,8 @@ class ImporterView : public views::View,
virtual void Layout();
// Overridden from views::DialogDelegate:
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual bool IsModal() const;
virtual std::wstring GetWindowTitle() const;
virtual bool Accept();
diff --git a/chrome/browser/views/importing_progress_view.cc b/chrome/browser/views/importing_progress_view.cc
index d7dcf81..dc97d8e 100644
--- a/chrome/browser/views/importing_progress_view.cc
+++ b/chrome/browser/views/importing_progress_view.cc
@@ -182,12 +182,12 @@ void ImportingProgressView::ViewHierarchyChanged(bool is_add,
// ImportingProgressView, views::DialogDelegate implementation:
int ImportingProgressView::GetDialogButtons() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
std::wstring ImportingProgressView::GetDialogButtonLabel(
- DialogButton button) const {
- DCHECK(button == DIALOGBUTTON_CANCEL);
+ MessageBox::DialogButton button) const {
+ DCHECK(button == MessageBox::DIALOGBUTTON_CANCEL);
return l10n_util::GetString(IDS_IMPORT_PROGRESS_STATUS_CANCEL);
}
diff --git a/chrome/browser/views/importing_progress_view.h b/chrome/browser/views/importing_progress_view.h
index 3ff77a5..77ee4a8 100644
--- a/chrome/browser/views/importing_progress_view.h
+++ b/chrome/browser/views/importing_progress_view.h
@@ -39,7 +39,7 @@ class ImportingProgressView : public views::View,
// Overridden from views::DialogDelegate:
virtual int GetDialogButtons() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const;
virtual bool IsModal() const;
virtual std::wstring GetWindowTitle() const;
virtual bool Cancel();
diff --git a/chrome/browser/views/input_window.cc b/chrome/browser/views/input_window.cc
index 8d8c24f..a038f09 100644
--- a/chrome/browser/views/input_window.cc
+++ b/chrome/browser/views/input_window.cc
@@ -33,7 +33,7 @@ class ContentView : public views::View,
}
// views::DialogDelegate overrides:
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual bool Accept();
virtual bool Cancel();
virtual void WindowClosing();
@@ -77,9 +77,11 @@ class ContentView : public views::View,
///////////////////////////////////////////////////////////////////////////////
// ContentView, views::DialogDelegate implementation:
-bool ContentView::IsDialogButtonEnabled(DialogButton button) const {
- if (button == DIALOGBUTTON_OK && !delegate_->IsValid(text_field_->GetText()))
+bool ContentView::IsDialogButtonEnabled(MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK &&
+ !delegate_->IsValid(text_field_->GetText())) {
return false;
+ }
return true;
}
diff --git a/chrome/browser/views/jsmessage_box_dialog.cc b/chrome/browser/views/jsmessage_box_dialog.cc
index bd0c7f2..028d46b 100644
--- a/chrome/browser/views/jsmessage_box_dialog.cc
+++ b/chrome/browser/views/jsmessage_box_dialog.cc
@@ -60,10 +60,10 @@ void JavascriptMessageBoxDialog::CloseModalDialog() {
int JavascriptMessageBoxDialog::GetDialogButtons() const {
int dialog_buttons = 0;
if (parent_->dialog_flags() & MessageBox::kFlagHasOKButton)
- dialog_buttons = DIALOGBUTTON_OK;
+ dialog_buttons = MessageBox::DIALOGBUTTON_OK;
if (parent_->dialog_flags() & MessageBox::kFlagHasCancelButton)
- dialog_buttons |= DIALOGBUTTON_CANCEL;
+ dialog_buttons |= MessageBox::DIALOGBUTTON_CANCEL;
return dialog_buttons;
}
@@ -96,11 +96,11 @@ bool JavascriptMessageBoxDialog::Accept() {
}
std::wstring JavascriptMessageBoxDialog::GetDialogButtonLabel(
- DialogButton button) const {
+ MessageBox::DialogButton button) const {
if (parent_->is_before_unload_dialog()) {
- if (button == DialogDelegate::DIALOGBUTTON_OK) {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
return l10n_util::GetString(IDS_BEFOREUNLOAD_MESSAGEBOX_OK_BUTTON_LABEL);
- } else if (button == DialogDelegate::DIALOGBUTTON_CANCEL) {
+ } else if (button == MessageBox::DIALOGBUTTON_CANCEL) {
return l10n_util::GetString(
IDS_BEFOREUNLOAD_MESSAGEBOX_CANCEL_BUTTON_LABEL);
}
diff --git a/chrome/browser/views/jsmessage_box_dialog.h b/chrome/browser/views/jsmessage_box_dialog.h
index 7195904..2fac473 100644
--- a/chrome/browser/views/jsmessage_box_dialog.h
+++ b/chrome/browser/views/jsmessage_box_dialog.h
@@ -37,7 +37,8 @@ class JavascriptMessageBoxDialog : public views::DialogDelegate {
virtual void DeleteDelegate();
virtual bool Cancel();
virtual bool Accept();
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
// views::WindowDelegate Methods:
virtual bool IsModal() const { return true; }
diff --git a/chrome/browser/views/keyword_editor_view.cc b/chrome/browser/views/keyword_editor_view.cc
index 4a4f064..7effbaf 100644
--- a/chrome/browser/views/keyword_editor_view.cc
+++ b/chrome/browser/views/keyword_editor_view.cc
@@ -444,7 +444,7 @@ std::wstring KeywordEditorView::GetWindowTitle() const {
}
int KeywordEditorView::GetDialogButtons() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
bool KeywordEditorView::Accept() {
diff --git a/chrome/browser/views/new_profile_dialog.cc b/chrome/browser/views/new_profile_dialog.cc
index fbb9c8e..5b4b903 100644
--- a/chrome/browser/views/new_profile_dialog.cc
+++ b/chrome/browser/views/new_profile_dialog.cc
@@ -46,10 +46,6 @@ NewProfileDialog::NewProfileDialog() {
NewProfileDialog::~NewProfileDialog() {
}
-int NewProfileDialog::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
views::View* NewProfileDialog::GetInitiallyFocusedView() {
views::TextField* text_box = message_box_view_->text_box();
DCHECK(text_box);
@@ -57,8 +53,8 @@ views::View* NewProfileDialog::GetInitiallyFocusedView() {
}
bool NewProfileDialog::IsDialogButtonEnabled(
- DialogButton button) const {
- if (button == DIALOGBUTTON_OK) {
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK) {
std::wstring profile_name = message_box_view_->GetInputText();
// TODO(munjal): Refactor the function ReplaceIllegalCharacters in
// file_util to something that just checks if there are illegal chars
diff --git a/chrome/browser/views/new_profile_dialog.h b/chrome/browser/views/new_profile_dialog.h
index 868480e..d4d25e1 100644
--- a/chrome/browser/views/new_profile_dialog.h
+++ b/chrome/browser/views/new_profile_dialog.h
@@ -30,9 +30,8 @@ class NewProfileDialog : public views::DialogDelegate,
// views::DialogDelegate methods.
virtual bool Accept();
- virtual int GetDialogButtons() const;
virtual views::View* GetInitiallyFocusedView();
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual std::wstring GetWindowTitle() const;
virtual void DeleteDelegate();
diff --git a/chrome/browser/views/options/advanced_page_view.cc b/chrome/browser/views/options/advanced_page_view.cc
index fcf083b..6a249a9 100644
--- a/chrome/browser/views/options/advanced_page_view.cc
+++ b/chrome/browser/views/options/advanced_page_view.cc
@@ -36,14 +36,11 @@ class ResetDefaultsConfirmBox : public views::DialogDelegate {
protected:
// views::DialogDelegate
- virtual int GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
- }
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const {
+ virtual std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const {
switch (button) {
- case DIALOGBUTTON_OK:
+ case MessageBox::DIALOGBUTTON_OK:
return l10n_util::GetString(IDS_OPTIONS_RESET_OKLABEL);
- case DIALOGBUTTON_CANCEL:
+ case MessageBox::DIALOGBUTTON_CANCEL:
return l10n_util::GetString(IDS_OPTIONS_RESET_CANCELLABEL);
default:
break;
diff --git a/chrome/browser/views/options/cookies_view.h b/chrome/browser/views/options/cookies_view.h
index 2baed44..58d04cb 100644
--- a/chrome/browser/views/options/cookies_view.h
+++ b/chrome/browser/views/options/cookies_view.h
@@ -55,7 +55,7 @@ class CookiesView : public views::View,
UINT flags);
// views::WindowDelegate implementation:
- virtual int GetDialogButtons() const { return DIALOGBUTTON_CANCEL; }
+ virtual int GetDialogButtons() const { return MessageBox::DIALOGBUTTON_CANCEL; }
virtual views::View* GetInitiallyFocusedView() {
return search_field_;
}
diff --git a/chrome/browser/views/options/options_window_view.cc b/chrome/browser/views/options/options_window_view.cc
index f7f492f..d2b324b 100644
--- a/chrome/browser/views/options/options_window_view.cc
+++ b/chrome/browser/views/options/options_window_view.cc
@@ -42,7 +42,7 @@ class OptionsWindowView : public views::View,
void ShowOptionsPage(OptionsPage page, OptionsGroup highlight_group);
// views::DialogDelegate implementation:
- virtual int GetDialogButtons() const { return DIALOGBUTTON_CANCEL; }
+ virtual int GetDialogButtons() const { return MessageBox::DIALOGBUTTON_CANCEL; }
virtual std::wstring GetWindowTitle() const;
virtual void WindowClosing();
virtual bool Cancel();
diff --git a/chrome/browser/views/options/passwords_exceptions_window_view.cc b/chrome/browser/views/options/passwords_exceptions_window_view.cc
index 9bf44b4..dbcfbf2 100644
--- a/chrome/browser/views/options/passwords_exceptions_window_view.cc
+++ b/chrome/browser/views/options/passwords_exceptions_window_view.cc
@@ -65,7 +65,7 @@ void PasswordsExceptionsWindowView::ViewHierarchyChanged(
// PasswordsExceptionsWindowView, views::DisloagDelegate implementations
int PasswordsExceptionsWindowView::GetDialogButtons() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
std::wstring PasswordsExceptionsWindowView::GetWindowTitle() const {
diff --git a/chrome/browser/views/page_info_window.cc b/chrome/browser/views/page_info_window.cc
index ecc3ef8..f1e2f31 100644
--- a/chrome/browser/views/page_info_window.cc
+++ b/chrome/browser/views/page_info_window.cc
@@ -597,7 +597,7 @@ void PageInfoWindow::Show() {
}
int PageInfoWindow::GetDialogButtons() const {
- return DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_CANCEL;
}
std::wstring PageInfoWindow::GetWindowTitle() const {
diff --git a/chrome/browser/views/repost_form_warning_view.cc b/chrome/browser/views/repost_form_warning_view.cc
index b8e9153..ca71237 100644
--- a/chrome/browser/views/repost_form_warning_view.cc
+++ b/chrome/browser/views/repost_form_warning_view.cc
@@ -57,10 +57,10 @@ std::wstring RepostFormWarningView::GetWindowTitle() const {
}
std::wstring RepostFormWarningView::GetDialogButtonLabel(
- DialogButton button) const {
- if (button == DialogDelegate::DIALOGBUTTON_OK)
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_HTTP_POST_WARNING_RESEND);
- if (button == DialogDelegate::DIALOGBUTTON_CANCEL)
+ if (button == MessageBox::DIALOGBUTTON_CANCEL)
return l10n_util::GetString(IDS_HTTP_POST_WARNING_CANCEL);
return L"";
}
diff --git a/chrome/browser/views/repost_form_warning_view.h b/chrome/browser/views/repost_form_warning_view.h
index a653922..092b02b 100644
--- a/chrome/browser/views/repost_form_warning_view.h
+++ b/chrome/browser/views/repost_form_warning_view.h
@@ -23,7 +23,8 @@ class RepostFormWarningView : public views::DialogDelegate,
// views::DialogDelegate Methods:
virtual std::wstring GetWindowTitle() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual void DeleteDelegate();
virtual bool Cancel();
virtual bool Accept();
diff --git a/chrome/browser/views/restart_message_box.cc b/chrome/browser/views/restart_message_box.cc
index e61e23f..f052ab1 100644
--- a/chrome/browser/views/restart_message_box.cc
+++ b/chrome/browser/views/restart_message_box.cc
@@ -21,12 +21,12 @@ void RestartMessageBox::ShowMessageBox(HWND parent_hwnd) {
}
int RestartMessageBox::GetDialogButtons() const {
- return DialogDelegate::DIALOGBUTTON_OK;
+ return MessageBox::DIALOGBUTTON_OK;
}
-std::wstring RestartMessageBox::GetDialogButtonLabel(DialogButton button)
- const {
- DCHECK(button == DIALOGBUTTON_OK);
+std::wstring RestartMessageBox::GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ DCHECK(button == MessageBox::DIALOGBUTTON_OK);
return l10n_util::GetString(IDS_OK);
}
diff --git a/chrome/browser/views/restart_message_box.h b/chrome/browser/views/restart_message_box.h
index 893bf43..6c9c12b 100644
--- a/chrome/browser/views/restart_message_box.h
+++ b/chrome/browser/views/restart_message_box.h
@@ -20,7 +20,7 @@ class RestartMessageBox : public views::DialogDelegate {
protected:
// views::DialogDelegate:
virtual int GetDialogButtons() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(MessageBox::DialogButton button) const;
virtual std::wstring GetWindowTitle() const;
// views::WindowDelegate:
diff --git a/chrome/browser/views/select_profile_dialog.cc b/chrome/browser/views/select_profile_dialog.cc
index b10c262..3a5c6d2 100644
--- a/chrome/browser/views/select_profile_dialog.cc
+++ b/chrome/browser/views/select_profile_dialog.cc
@@ -66,10 +66,6 @@ void SelectProfileDialog::Layout() {
GetLayoutManager()->Layout(this);
}
-int SelectProfileDialog::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
views::View* SelectProfileDialog::GetInitiallyFocusedView() {
return profile_combobox_;
}
diff --git a/chrome/browser/views/select_profile_dialog.h b/chrome/browser/views/select_profile_dialog.h
index a761623..723efb2 100644
--- a/chrome/browser/views/select_profile_dialog.h
+++ b/chrome/browser/views/select_profile_dialog.h
@@ -50,7 +50,6 @@ class SelectProfileDialog
virtual bool Accept();
virtual bool Cancel();
virtual views::View* GetContentsView();
- virtual int GetDialogButtons() const;
virtual views::View* GetInitiallyFocusedView();
virtual std::wstring GetWindowTitle() const;
virtual bool IsModal() const { return false; }
diff --git a/chrome/browser/views/shelf_item_dialog.cc b/chrome/browser/views/shelf_item_dialog.cc
index 68050b1..32a32f9 100644
--- a/chrome/browser/views/shelf_item_dialog.cc
+++ b/chrome/browser/views/shelf_item_dialog.cc
@@ -375,8 +375,9 @@ bool ShelfItemDialog::IsModal() const {
return true;
}
-std::wstring ShelfItemDialog::GetDialogButtonLabel(DialogButton button) const {
- if (button == DialogDelegate::DIALOGBUTTON_OK)
+std::wstring ShelfItemDialog::GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return l10n_util::GetString(IDS_ASI_ADD);
return std::wstring();
}
@@ -426,7 +427,7 @@ void ShelfItemDialog::ContentsChanged(views::TextField* sender,
}
bool ShelfItemDialog::Accept() {
- if (!IsDialogButtonEnabled(DIALOGBUTTON_OK)) {
+ if (!IsDialogButtonEnabled(MessageBox::DIALOGBUTTON_OK)) {
if (!GetInputURL().is_valid())
url_field_->RequestFocus();
else if (title_field_)
@@ -437,8 +438,9 @@ bool ShelfItemDialog::Accept() {
return true;
}
-bool ShelfItemDialog::IsDialogButtonEnabled(DialogButton button) const {
- if (button == DIALOGBUTTON_OK)
+bool ShelfItemDialog::IsDialogButtonEnabled(
+ MessageBox::DialogButton button) const {
+ if (button == MessageBox::DIALOGBUTTON_OK)
return GetInputURL().is_valid();
return true;
}
diff --git a/chrome/browser/views/shelf_item_dialog.h b/chrome/browser/views/shelf_item_dialog.h
index 9e5520d..40b2020 100644
--- a/chrome/browser/views/shelf_item_dialog.h
+++ b/chrome/browser/views/shelf_item_dialog.h
@@ -59,9 +59,10 @@ class ShelfItemDialog : public views::View,
// DialogDelegate.
virtual std::wstring GetWindowTitle() const;
virtual bool IsModal() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual bool Accept();
- virtual bool IsDialogButtonEnabled(DialogButton button) const;
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const;
virtual views::View* GetContentsView();
// TextField::Controller.
diff --git a/chrome/browser/views/uninstall_dialog.cc b/chrome/browser/views/uninstall_dialog.cc
index da54ca8..c8faee9 100644
--- a/chrome/browser/views/uninstall_dialog.cc
+++ b/chrome/browser/views/uninstall_dialog.cc
@@ -30,10 +30,6 @@ bool UninstallDialog::Cancel() {
return true;
}
-int UninstallDialog::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-}
-
std::wstring UninstallDialog::GetWindowTitle() const {
return l10n_util::GetString(IDS_UNINSTALL_CHROME);
}
diff --git a/chrome/browser/views/uninstall_dialog.h b/chrome/browser/views/uninstall_dialog.h
index 0874db6..bf9a6c9 100644
--- a/chrome/browser/views/uninstall_dialog.h
+++ b/chrome/browser/views/uninstall_dialog.h
@@ -20,7 +20,6 @@ class UninstallDialog : public views::DialogDelegate {
// Overridden from views::DialogDelegate:
virtual bool Accept();
virtual bool Cancel();
- virtual int GetDialogButtons() const;
virtual std::wstring GetWindowTitle() const;
// Overridden from views::WindowDelegate:
diff --git a/chrome/browser/views/user_data_dir_dialog.cc b/chrome/browser/views/user_data_dir_dialog.cc
index 3598950..e5a2a8c 100644
--- a/chrome/browser/views/user_data_dir_dialog.cc
+++ b/chrome/browser/views/user_data_dir_dialog.cc
@@ -37,19 +37,14 @@ UserDataDirDialog::~UserDataDirDialog() {
select_file_dialog_->ListenerDestroyed();
}
-int UserDataDirDialog::GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
-
-}
-
std::wstring UserDataDirDialog::GetDialogButtonLabel(
- DialogButton button) const {
+ MessageBox::DialogButton button) const {
switch (button) {
- case DIALOGBUTTON_OK:
+ case MessageBox::DIALOGBUTTON_OK:
return l10n_util::GetString(
IDS_CANT_WRITE_USER_DIRECTORY_CHOOSE_DIRECTORY_BUTTON);
- case DIALOGBUTTON_CANCEL:
+ case MessageBox::DIALOGBUTTON_CANCEL:
return l10n_util::GetString(IDS_CANT_WRITE_USER_DIRECTORY_EXIT_BUTTON);
default:
NOTREACHED();
diff --git a/chrome/browser/views/user_data_dir_dialog.h b/chrome/browser/views/user_data_dir_dialog.h
index 78192ce..35ee6d7 100644
--- a/chrome/browser/views/user_data_dir_dialog.h
+++ b/chrome/browser/views/user_data_dir_dialog.h
@@ -32,8 +32,8 @@ class UserDataDirDialog : public views::DialogDelegate,
std::wstring user_data_dir() { return user_data_dir_; }
// views::DialogDelegate Methods:
- virtual int GetDialogButtons() const;
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const;
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const;
virtual std::wstring GetWindowTitle() const;
virtual void DeleteDelegate();
virtual bool Accept();
diff --git a/chrome/common/message_box_flags.h b/chrome/common/message_box_flags.h
index 40047d9..b2daf38 100644
--- a/chrome/common/message_box_flags.h
+++ b/chrome/common/message_box_flags.h
@@ -42,6 +42,13 @@ class MessageBox {
static const int kIsJavascriptPrompt = kIsJavascriptConfirm |
kFlagHasPromptField;
+ // Dialog button identifiers used to specify which buttons to show the user.
+ enum DialogButton {
+ DIALOGBUTTON_NONE = 0, // No dialog buttons, for WindowType == WINDOW.
+ DIALOGBUTTON_OK = 1, // Has an OK button.
+ DIALOGBUTTON_CANCEL = 2, // Has a Cancel button (becomes a Close button if
+ }; // no OK button).
+
private:
MessageBox() {}
DISALLOW_COPY_AND_ASSIGN(MessageBox);
diff --git a/chrome/common/temp_scaffolding_stubs.cc b/chrome/common/temp_scaffolding_stubs.cc
index 8d2fbff..4dcb220 100644
--- a/chrome/common/temp_scaffolding_stubs.cc
+++ b/chrome/common/temp_scaffolding_stubs.cc
@@ -119,16 +119,6 @@ void AutomationProvider::OnMessageFromExternalHost(
NOTIMPLEMENTED();
}
-void AutomationProvider::GetShowingAppModalDialog(bool* showing_dialog,
- int* dialog_button) {
- NOTIMPLEMENTED();
-}
-
-void AutomationProvider::ClickAppModalDialogButton(int button, bool* success) {
- *success = false;
- NOTIMPLEMENTED();
-}
-
//--------------------------------------------------------------------------
bool ShellIntegration::SetAsDefaultBrowser() {
diff --git a/chrome/test/automation/automation_proxy.cc b/chrome/test/automation/automation_proxy.cc
index 5715aac..fac5001 100644
--- a/chrome/test/automation/automation_proxy.cc
+++ b/chrome/test/automation/automation_proxy.cc
@@ -318,11 +318,9 @@ bool AutomationProxy::WaitForWindowCountToBecome(int count,
return false;
}
-#if defined(OS_WIN)
-// TODO(port): Port when DialogDelegate is ported.
bool AutomationProxy::GetShowingAppModalDialog(
bool* showing_app_modal_dialog,
- views::DialogDelegate::DialogButton* button) {
+ MessageBox::DialogButton* button) {
if (!showing_app_modal_dialog || !button) {
NOTREACHED();
return false;
@@ -338,12 +336,12 @@ bool AutomationProxy::GetShowingAppModalDialog(
return false;
}
- *button = static_cast<views::DialogDelegate::DialogButton>(button_int);
+ *button = static_cast<MessageBox::DialogButton>(button_int);
return true;
}
bool AutomationProxy::ClickAppModalDialogButton(
- views::DialogDelegate::DialogButton button) {
+ MessageBox::DialogButton button) {
bool succeeded = false;
if (!SendWithTimeout(
@@ -361,8 +359,7 @@ bool AutomationProxy::WaitForAppModalDialog(int wait_timeout) {
const TimeDelta timeout = TimeDelta::FromMilliseconds(wait_timeout);
while (TimeTicks::Now() - start < timeout) {
bool dialog_shown = false;
- views::DialogDelegate::DialogButton button =
- views::DialogDelegate::DIALOGBUTTON_NONE;
+ MessageBox::DialogButton button = MessageBox::DIALOGBUTTON_NONE;
bool succeeded = GetShowingAppModalDialog(&dialog_shown, &button);
if (!succeeded) {
// Try again next round, but log it.
@@ -370,12 +367,11 @@ bool AutomationProxy::WaitForAppModalDialog(int wait_timeout) {
} else if (dialog_shown) {
return true;
}
- Sleep(automation::kSleepTime);
+ PlatformThread::Sleep(automation::kSleepTime);
}
// Dialog never shown.
return false;
}
-#endif // defined(OS_WIN)
bool AutomationProxy::WaitForURLDisplayed(GURL url, int wait_timeout) {
const TimeTicks start = TimeTicks::Now();
diff --git a/chrome/test/automation/automation_proxy.h b/chrome/test/automation/automation_proxy.h
index e9d55d1..9b052a8 100644
--- a/chrome/test/automation/automation_proxy.h
+++ b/chrome/test/automation/automation_proxy.h
@@ -16,14 +16,10 @@
#include "chrome/common/ipc_channel_proxy.h"
#include "chrome/common/ipc_message.h"
#include "chrome/common/ipc_sync_channel.h"
+#include "chrome/common/message_box_flags.h"
#include "chrome/test/automation/automation_handle_tracker.h"
#include "chrome/test/automation/automation_messages.h"
-#if defined(OS_WIN)
-// TODO(port): Enable this or equivalent.
-#include "chrome/views/window/dialog_delegate.h"
-#endif
-
class AutomationRequest;
class BrowserProxy;
class TabProxy;
@@ -98,17 +94,13 @@ class AutomationProxy : public IPC::Channel::Listener,
// Returns true on success.
bool WaitForWindowCountToBecome(int target_count, int wait_timeout);
-#if defined(OS_WIN)
- // TODO(port): Enable when we have portable DialogDelegate.
-
// Returns whether an app modal dialog window is showing right now (i.e., a
// javascript alert), and what buttons it contains.
bool GetShowingAppModalDialog(bool* showing_app_modal_dialog,
- views::DialogDelegate::DialogButton* button);
+ MessageBox::DialogButton* button);
// Simulates a click on a dialog button.
- bool ClickAppModalDialogButton(views::DialogDelegate::DialogButton button);
-#endif // defined(OS_WIN)
+ bool ClickAppModalDialogButton(MessageBox::DialogButton button);
// Block the thread until a modal dialog is displayed. Returns true on
// success.
diff --git a/chrome/test/automation/automation_proxy_uitest.cc b/chrome/test/automation/automation_proxy_uitest.cc
index 464fa81..bd5495a 100644
--- a/chrome/test/automation/automation_proxy_uitest.cc
+++ b/chrome/test/automation/automation_proxy_uitest.cc
@@ -1005,12 +1005,11 @@ TEST_F(AutomationProxyTest, DISABLED_AppModalDialogTest) {
ASSERT_TRUE(tab.get());
bool modal_dialog_showing = false;
- views::DialogDelegate::DialogButton button =
- views::DialogDelegate::DIALOGBUTTON_NONE;
+ MessageBox::DialogButton button = MessageBox::DIALOGBUTTON_NONE;
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_FALSE(modal_dialog_showing);
- EXPECT_EQ(views::DialogDelegate::DIALOGBUTTON_NONE, button);
+ EXPECT_EQ(MessageBox::DIALOGBUTTON_NONE, button);
// Show a simple alert.
std::string content =
@@ -1022,19 +1021,19 @@ TEST_F(AutomationProxyTest, DISABLED_AppModalDialogTest) {
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_TRUE(modal_dialog_showing);
- EXPECT_EQ(views::DialogDelegate::DIALOGBUTTON_OK, button);
+ EXPECT_EQ(MessageBox::DIALOGBUTTON_OK, button);
// Test that clicking missing button fails graciously and does not close the
// dialog.
EXPECT_FALSE(automation()->ClickAppModalDialogButton(
- views::DialogDelegate::DIALOGBUTTON_CANCEL));
+ MessageBox::DIALOGBUTTON_CANCEL));
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_TRUE(modal_dialog_showing);
// Now click OK, that should close the dialog.
EXPECT_TRUE(automation()->ClickAppModalDialogButton(
- views::DialogDelegate::DIALOGBUTTON_OK));
+ MessageBox::DIALOGBUTTON_OK));
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_FALSE(modal_dialog_showing);
@@ -1049,12 +1048,12 @@ TEST_F(AutomationProxyTest, DISABLED_AppModalDialogTest) {
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_TRUE(modal_dialog_showing);
- EXPECT_EQ(views::DialogDelegate::DIALOGBUTTON_OK |
- views::DialogDelegate::DIALOGBUTTON_CANCEL, button);
+ EXPECT_EQ(MessageBox::DIALOGBUTTON_OK |
+ MessageBox::DIALOGBUTTON_CANCEL, button);
// Click OK.
EXPECT_TRUE(automation()->ClickAppModalDialogButton(
- views::DialogDelegate::DIALOGBUTTON_OK));
+ MessageBox::DIALOGBUTTON_OK));
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_FALSE(modal_dialog_showing);
@@ -1069,12 +1068,12 @@ TEST_F(AutomationProxyTest, DISABLED_AppModalDialogTest) {
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_TRUE(modal_dialog_showing);
- EXPECT_EQ(views::DialogDelegate::DIALOGBUTTON_OK |
- views::DialogDelegate::DIALOGBUTTON_CANCEL, button);
+ EXPECT_EQ(MessageBox::DIALOGBUTTON_OK |
+ MessageBox::DIALOGBUTTON_CANCEL, button);
// Click Cancel this time.
EXPECT_TRUE(automation()->ClickAppModalDialogButton(
- views::DialogDelegate::DIALOGBUTTON_CANCEL));
+ MessageBox::DIALOGBUTTON_CANCEL));
EXPECT_TRUE(automation()->GetShowingAppModalDialog(&modal_dialog_showing,
&button));
EXPECT_FALSE(modal_dialog_showing);
diff --git a/chrome/views/view_unittest.cc b/chrome/views/view_unittest.cc
index 9fbf481..432a47b 100644
--- a/chrome/views/view_unittest.cc
+++ b/chrome/views/view_unittest.cc
@@ -843,12 +843,8 @@ class TestDialogView : public views::View,
}
// views::DialogDelegate implementation:
- virtual int GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
- }
-
virtual int GetDefaultDialogButton() const {
- return DIALOGBUTTON_OK;
+ return MessageBox::DIALOGBUTTON_OK;
}
virtual View* GetContentsView() {
diff --git a/chrome/views/window/dialog_client_view.cc b/chrome/views/window/dialog_client_view.cc
index 542439d..0a8294f 100644
--- a/chrome/views/window/dialog_client_view.cc
+++ b/chrome/views/window/dialog_client_view.cc
@@ -27,7 +27,7 @@ namespace {
// Updates any of the standard buttons according to the delegate.
void UpdateButtonHelper(NativeButton* button_view,
DialogDelegate* delegate,
- DialogDelegate::DialogButton button) {
+ MessageBox::DialogButton button) {
std::wstring label = delegate->GetDialogButtonLabel(button);
if (!label.empty())
button_view->SetLabel(label);
@@ -50,7 +50,7 @@ class DialogButton : public NativeButton {
public:
DialogButton(ButtonListener* listener,
Window* owner,
- DialogDelegate::DialogButton type,
+ MessageBox::DialogButton type,
const std::wstring& title,
bool is_default)
: NativeButton(listener, title),
@@ -70,7 +70,7 @@ class DialogButton : public NativeButton {
private:
Window* owner_;
- const DialogDelegate::DialogButton type_;
+ const MessageBox::DialogButton type_;
DISALLOW_COPY_AND_ASSIGN(DialogButton);
};
@@ -106,38 +106,38 @@ DialogClientView::~DialogClientView() {
void DialogClientView::ShowDialogButtons() {
DialogDelegate* dd = GetDialogDelegate();
int buttons = dd->GetDialogButtons();
- if (buttons & DialogDelegate::DIALOGBUTTON_OK && !ok_button_) {
+ if (buttons & MessageBox::DIALOGBUTTON_OK && !ok_button_) {
std::wstring label =
- dd->GetDialogButtonLabel(DialogDelegate::DIALOGBUTTON_OK);
+ dd->GetDialogButtonLabel(MessageBox::DIALOGBUTTON_OK);
if (label.empty())
label = l10n_util::GetString(IDS_OK);
bool is_default_button =
- (dd->GetDefaultDialogButton() & DialogDelegate::DIALOGBUTTON_OK) != 0;
+ (dd->GetDefaultDialogButton() & MessageBox::DIALOGBUTTON_OK) != 0;
ok_button_ = new DialogButton(this, window(),
- DialogDelegate::DIALOGBUTTON_OK, label,
+ MessageBox::DIALOGBUTTON_OK, label,
is_default_button);
ok_button_->SetGroup(kButtonGroup);
if (is_default_button)
default_button_ = ok_button_;
- if (!(buttons & DialogDelegate::DIALOGBUTTON_CANCEL))
+ if (!(buttons & MessageBox::DIALOGBUTTON_CANCEL))
ok_button_->AddAccelerator(Accelerator(VK_ESCAPE, false, false, false));
AddChildView(ok_button_);
}
- if (buttons & DialogDelegate::DIALOGBUTTON_CANCEL && !cancel_button_) {
+ if (buttons & MessageBox::DIALOGBUTTON_CANCEL && !cancel_button_) {
std::wstring label =
- dd->GetDialogButtonLabel(DialogDelegate::DIALOGBUTTON_CANCEL);
+ dd->GetDialogButtonLabel(MessageBox::DIALOGBUTTON_CANCEL);
if (label.empty()) {
- if (buttons & DialogDelegate::DIALOGBUTTON_OK) {
+ if (buttons & MessageBox::DIALOGBUTTON_OK) {
label = l10n_util::GetString(IDS_CANCEL);
} else {
label = l10n_util::GetString(IDS_CLOSE);
}
}
bool is_default_button =
- (dd->GetDefaultDialogButton() & DialogDelegate::DIALOGBUTTON_CANCEL)
+ (dd->GetDefaultDialogButton() & MessageBox::DIALOGBUTTON_CANCEL)
!= 0;
cancel_button_ = new DialogButton(this, window(),
- DialogDelegate::DIALOGBUTTON_CANCEL,
+ MessageBox::DIALOGBUTTON_CANCEL,
label, is_default_button);
cancel_button_->SetGroup(kButtonGroup);
cancel_button_->AddAccelerator(Accelerator(VK_ESCAPE, false, false, false));
@@ -174,9 +174,9 @@ void DialogClientView::FocusWillChange(View* focused_before,
// The focused view is not a button, get the default button from the
// delegate.
DialogDelegate* dd = GetDialogDelegate();
- if ((dd->GetDefaultDialogButton() & DialogDelegate::DIALOGBUTTON_OK) != 0)
+ if ((dd->GetDefaultDialogButton() & MessageBox::DIALOGBUTTON_OK) != 0)
new_default_button = ok_button_;
- if ((dd->GetDefaultDialogButton() & DialogDelegate::DIALOGBUTTON_CANCEL)
+ if ((dd->GetDefaultDialogButton() & MessageBox::DIALOGBUTTON_CANCEL)
!= 0)
new_default_button = cancel_button_;
}
@@ -188,11 +188,11 @@ void DialogClientView::UpdateDialogButtons() {
DialogDelegate* dd = GetDialogDelegate();
int buttons = dd->GetDialogButtons();
- if (buttons & DialogDelegate::DIALOGBUTTON_OK)
- UpdateButtonHelper(ok_button_, dd, DialogDelegate::DIALOGBUTTON_OK);
+ if (buttons & MessageBox::DIALOGBUTTON_OK)
+ UpdateButtonHelper(ok_button_, dd, MessageBox::DIALOGBUTTON_OK);
- if (buttons & DialogDelegate::DIALOGBUTTON_CANCEL)
- UpdateButtonHelper(cancel_button_, dd, DialogDelegate::DIALOGBUTTON_CANCEL);
+ if (buttons & MessageBox::DIALOGBUTTON_CANCEL)
+ UpdateButtonHelper(cancel_button_, dd, MessageBox::DIALOGBUTTON_CANCEL);
LayoutDialogButtons();
SchedulePaint();
@@ -224,9 +224,9 @@ bool DialogClientView::CanClose() const {
if (!accepted_) {
DialogDelegate* dd = GetDialogDelegate();
int buttons = dd->GetDialogButtons();
- if (buttons & DialogDelegate::DIALOGBUTTON_CANCEL)
+ if (buttons & MessageBox::DIALOGBUTTON_CANCEL)
return dd->Cancel();
- if (buttons & DialogDelegate::DIALOGBUTTON_OK)
+ if (buttons & MessageBox::DIALOGBUTTON_OK)
return dd->Accept(true);
}
return true;
@@ -352,7 +352,7 @@ void DialogClientView::PaintSizeBox(ChromeCanvas* canvas) {
int DialogClientView::GetButtonWidth(int button) const {
DialogDelegate* dd = GetDialogDelegate();
std::wstring button_label = dd->GetDialogButtonLabel(
- static_cast<DialogDelegate::DialogButton>(button));
+ static_cast<MessageBox::DialogButton>(button));
int string_width = dialog_button_font_->GetStringWidth(button_label);
return std::max(string_width + kDialogButtonLabelSpacing,
kDialogMinButtonWidth);
@@ -372,7 +372,7 @@ void DialogClientView::LayoutDialogButtons() {
if (cancel_button_) {
gfx::Size ps = cancel_button_->GetPreferredSize();
gfx::Rect lb = GetLocalBounds(false);
- int button_width = GetButtonWidth(DialogDelegate::DIALOGBUTTON_CANCEL);
+ int button_width = GetButtonWidth(MessageBox::DIALOGBUTTON_CANCEL);
int button_x = lb.right() - button_width - kButtonHEdgeMargin;
int button_y = lb.bottom() - ps.height() - kButtonVEdgeMargin;
cancel_button_->SetBounds(button_x, button_y, button_width, ps.height());
@@ -383,7 +383,7 @@ void DialogClientView::LayoutDialogButtons() {
if (ok_button_) {
gfx::Size ps = ok_button_->GetPreferredSize();
gfx::Rect lb = GetLocalBounds(false);
- int button_width = GetButtonWidth(DialogDelegate::DIALOGBUTTON_OK);
+ int button_width = GetButtonWidth(MessageBox::DIALOGBUTTON_OK);
int ok_button_right = lb.right() - kButtonHEdgeMargin;
if (cancel_button_)
ok_button_right = cancel_button_->x() - kRelatedButtonHSpacing;
diff --git a/chrome/views/window/dialog_delegate.cc b/chrome/views/window/dialog_delegate.cc
index 9778066..80d0e8b 100644
--- a/chrome/views/window/dialog_delegate.cc
+++ b/chrome/views/window/dialog_delegate.cc
@@ -13,18 +13,18 @@ namespace views {
// Overridden from WindowDelegate:
int DialogDelegate::GetDefaultDialogButton() const {
- if (GetDialogButtons() & DIALOGBUTTON_OK)
- return DIALOGBUTTON_OK;
- if (GetDialogButtons() & DIALOGBUTTON_CANCEL)
- return DIALOGBUTTON_CANCEL;
- return DIALOGBUTTON_NONE;
+ if (GetDialogButtons() & MessageBox::DIALOGBUTTON_OK)
+ return MessageBox::DIALOGBUTTON_OK;
+ if (GetDialogButtons() & MessageBox::DIALOGBUTTON_CANCEL)
+ return MessageBox::DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_NONE;
}
View* DialogDelegate::GetInitiallyFocusedView() {
// Focus the default button if any.
DialogClientView* dcv = GetDialogClientView();
int default_button = GetDefaultDialogButton();
- if (default_button == DIALOGBUTTON_NONE)
+ if (default_button == MessageBox::DIALOGBUTTON_NONE)
return NULL;
if ((default_button & GetDialogButtons()) == 0) {
@@ -33,9 +33,9 @@ View* DialogDelegate::GetInitiallyFocusedView() {
return NULL;
}
- if (default_button & DIALOGBUTTON_OK)
+ if (default_button & MessageBox::DIALOGBUTTON_OK)
return dcv->ok_button();
- if (default_button & DIALOGBUTTON_CANCEL)
+ if (default_button & MessageBox::DIALOGBUTTON_CANCEL)
return dcv->cancel_button();
return NULL;
}
diff --git a/chrome/views/window/dialog_delegate.h b/chrome/views/window/dialog_delegate.h
index b8b2d1b..0705703 100644
--- a/chrome/views/window/dialog_delegate.h
+++ b/chrome/views/window/dialog_delegate.h
@@ -5,6 +5,7 @@
#ifndef CHROME_VIEWS_WINDOW_DIALOG_DELEGATE_H_
#define CHROME_VIEWS_WINDOW_DIALOG_DELEGATE_H_
+#include "chrome/common/message_box_flags.h"
#include "chrome/views/window/dialog_client_view.h"
#include "chrome/views/window/window_delegate.h"
@@ -26,12 +27,6 @@ class DialogDelegate : public WindowDelegate {
public:
virtual DialogDelegate* AsDialogDelegate() { return this; }
- enum DialogButton {
- DIALOGBUTTON_NONE = 0, // No dialog buttons, for WindowType == WINDOW.
- DIALOGBUTTON_OK = 1, // Has an OK button.
- DIALOGBUTTON_CANCEL = 2, // Has a Cancel button (becomes a Close button if
- }; // no OK button).
-
// Returns a mask specifying which of the available DialogButtons are visible
// for the dialog. Note: If an OK button is provided, you should provide a
// CANCEL button. A dialog box with just an OK button is frowned upon and
@@ -40,18 +35,21 @@ class DialogDelegate : public WindowDelegate {
//
// To use the extra button you need to override GetDialogButtons()
virtual int GetDialogButtons() const {
- return DIALOGBUTTON_OK | DIALOGBUTTON_CANCEL;
+ return MessageBox::DIALOGBUTTON_OK | MessageBox::DIALOGBUTTON_CANCEL;
}
// Returns whether accelerators are enabled on the button. This is invoked
// when an accelerator is pressed, not at construction time. This
// returns true.
- virtual bool AreAcceleratorsEnabled(DialogButton button) { return true; }
+ virtual bool AreAcceleratorsEnabled(MessageBox::DialogButton button) {
+ return true;
+ }
// Returns the label of the specified DialogButton.
- virtual std::wstring GetDialogButtonLabel(DialogButton button) const {
- // empty string results in defaults for DIALOGBUTTON_OK,
- // DIALOGBUTTON_CANCEL.
+ virtual std::wstring GetDialogButtonLabel(
+ MessageBox::DialogButton button) const {
+ // empty string results in defaults for MessageBox::DIALOGBUTTON_OK,
+ // MessageBox::DIALOGBUTTON_CANCEL.
return L"";
}
@@ -60,20 +58,21 @@ class DialogDelegate : public WindowDelegate {
// up to the buttons.
virtual View* GetExtraView() { return NULL; }
// Returns the default dialog button. This should not be a mask as only one
// button should ever be the default button. Return DIALOGBUTTON_NONE if
// there is no default. Default behavior is to return DIALOGBUTTON_OK or
// DIALOGBUTTON_CANCEL (in that order) if they are present, DIALOGBUTTON_NONE
// otherwise.
virtual int GetDefaultDialogButton() const;
// Returns whether the specified dialog button is enabled.
- virtual bool IsDialogButtonEnabled(DialogButton button) const {
+ virtual bool IsDialogButtonEnabled(MessageBox::DialogButton button) const {
return true;
}
// Returns whether the specified dialog button is visible.
- virtual bool IsDialogButtonVisible(DialogButton button) const {
+ virtual bool IsDialogButtonVisible(MessageBox::DialogButton button) const {
return true;
}
@@ -60,20 +58,21 @@ class DialogDelegate : public WindowDelegate {
// up to the buttons.
virtual View* GetExtraView() { return NULL; }
- // Returns the default dialog button. This should not be a mask as only one
- // button should ever be the default button. Return DIALOGBUTTON_NONE if
- // there is no default. Default behavior is to return DIALOGBUTTON_OK or
- // DIALOGBUTTON_CANCEL (in that order) if they are present, DIALOGBUTTON_NONE
- // otherwise.
+ // Returns the default dialog button. This should not be a mask as only
+ // one button should ever be the default button. Return
+ // MessageBox::DIALOGBUTTON_NONE if there is no default. Default behavior
+ // is to return MessageBox::DIALOGBUTTON_OK or
+ // MessageBox::DIALOGBUTTON_CANCEL (in that order) if they are present,
+ // MessageBox::DIALOGBUTTON_NONE otherwise.
virtual int GetDefaultDialogButton() const;
// Returns whether the specified dialog button is enabled.